(function( $ ) {
	'use strict';

	$( document ).ready( function() {
		//Get all Quiz modules on the page
		var tmqzAllMods = $( '.tm-quiz-container' );
		//loop through and assign objects.
		for ( var i = 0, len = tmqzAllMods.length; i < len; i++ ) {
			TMQZ.ActivateQuiz(tmqzAllMods[i]);
		}
	});

})( jQuery );

var quizConfiguration = {};
quizConfiguration.location = '/wp-content/plugins/disney-quizzes-plugin/public/';
quizConfiguration.base = ['common/css/main.min.css', 'common/css/disney-quizzes-default.min.css', 'common/js/vendor/picturefill.min.js', 'common/js/disney-quizzes-class.js'];
quizConfiguration.eitheror = ['eitheror/css/disney-quizzes-eitheror.css', 'eitheror/js/disney-quizzes-eitheror.js', 'eitheror/js/jquery.touchSwipe.min.js', 'eitheror/js/jquery.easing.1.3.1.min.js'];
quizConfiguration.reveal = ['reveal/css/disney-quizzes-reveal.min.css', 'reveal/js/disney-quizzes-reveal.js'];
quizConfiguration.trivia = ['trivia/js/disney-quizzes-trivia.js'];
quizConfiguration.personality = ['common/css/disney-quizzes-default.min.css', 'personality/js/disney-quizzes-personality.js'];
quizConfiguration['type-to-answer'] = ['typetoanswer/css/disney-quizzes-typetoanswer.min.css', 'typetoanswer/js/disney-quizzes-typetoanswer.js'];
quizConfiguration.educational = ['educational/css/disney-quizzes-educational.min.css', 'educational/js/disney-quizzes-educational.js'];
quizConfiguration.challenge = ['challenge/js/disney-quizzes-challenge.js'];
quizConfiguration.poll = ['poll/css/disney-quizzes-poll.min.css', 'poll/js/disney-quizzes-poll.js'];

var TMQZ = TMQZ || {};

TMQZ.GetQuizKlass = function(quizType) {
	switch( quizType ) {
		case 'eitheror':
			return TMQZ.EitherOrQuiz;
		case 'reveal' :
			return TMQZ.RevealQuiz;
		case 'trivia' :
			return TMQZ.TriviaQuiz;
		case 'personality' :
			return TMQZ.PersonalityQuiz;
		case 'type-to-answer':
			return TMQZ.TypeToAnswerQuiz;
		case 'challenge' :
			return TMQZ.ChallengeQuiz;
		case 'educational' :
			return TMQZ.EducationalQuiz;
		case 'poll' :
			return TMQZ.Polls;
		default :
			break;
	}
	return null;
};

TMQZ.ActivateQuiz = function(quizContainer) {
	var quizType = quizContainer.getAttribute( 'data-role' ).toLowerCase();
	// check if CSS and JS is loaded
	var QuizKlass = TMQZ.GetQuizKlass(quizType);
	if( typeof QuizKlass === "undefined" ) {
		var dependencies = quizConfiguration.base;
		var quizDependencies = quizConfiguration[quizType];
		if(quizDependencies !== null) {
			for(var i=0; i<quizDependencies.length; i++) {
				dependencies.push(quizDependencies[i]);
			}
		}
		// this type of quiz does not have their dependencies loaded
		TMQZ.LoadDependencies(quizContainer, quizType, dependencies);
	} else {
		TMQZ.StartQuizContent(quizContainer, QuizKlass);
	}
};

TMQZ.LoadDependencies = function(quizContainer, quizType, dependencies) {
	// recursively load specific dependencies
	if(dependencies.length > 0) {
		var asset = quizConfiguration.location + dependencies.shift();
		if(asset.indexOf('.css') > -1) {
			var css = document.createElement( 'link' );
			css.rel = 'stylesheet';
			css.href= asset;
			document.getElementsByTagName( 'head' )[0].appendChild( css );

			//  keep loading assets
			TMQZ.LoadDependencies( quizContainer, quizType, dependencies );
		} else {
			$.getScript(asset, function(data, textStatus, jqxhr) {
				// keep loading assets
				TMQZ.LoadDependencies(quizContainer, quizType, dependencies);
			});
		}
	} else {
		TMQZ.StartQuizContent(quizContainer, TMQZ.GetQuizKlass(quizType));
	}
};

TMQZ.StartQuizContent = function(quizContainer, QuizKlass) {
	if(quizContainer.getAttribute('quiz-initialized') === null) {
		var pollType = $( '.tm-quiz-container' ).hasClass( 'quiz-poll' ) ? 'poll_start' : 'quiz_start';

		// does the tracking need to fire whenever a quiz is loaded?
		if (window.cto) {
			cto.trackEvent( {'engagementType': pollType} );
		}

		var quizObject = new QuizKlass(quizContainer);
		var tmqzWin = $( window );
		if(quizObject.resize) {
			tmqzWin.resize(function () {
				quizObject.resize();
			});
		}
		quizContainer.setAttribute('quiz-initialized', 'true');
	}
};
